@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: GIF.pm,v 1.6 2004/06/07 19:44:44 fredo Exp $
+#   $Id: GIF.pm,v 1.7 2004/06/15 09:14:54 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
     use vars qw(@ISA $VERSION);
     @ISA = qw( PDF::API2::Resource::XObject::Image );
 
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:44 $
+    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:54 $
 
 }
 
@@ -286,6 +286,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: GIF.pm,v $
+    Revision 1.7  2004/06/15 09:14:54  fredo
+    removed cr+lf
+
     Revision 1.6  2004/06/07 19:44:44  fredo
     cleaned out cr+lf for lf
 
