@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Win32.pm,v 1.5 2004/06/07 19:44:13 fredo Exp $
+#   $Id: Win32.pm,v 1.6 2004/06/15 09:11:38 fredo Exp $
 #
 #=======================================================================
 
 package PDF::API2::Win32;
 
     use vars qw($VERSION);
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:13 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:11:38 $
 
 
 package PDF::API2;
@@ -118,6 +118,9 @@ __END__
 =head1 HISTORY
 
     $Log: Win32.pm,v $
+    Revision 1.6  2004/06/15 09:11:38  fredo
+    removed cr+lf
+
     Revision 1.5  2004/06/07 19:44:13  fredo
     cleaned out cr+lf for lf
 
